function Chan = Rayleigh (osrate, N, T)
% July 16th, 2008
% Modified: Feb 20th, 2009
% Edited by Ali Tawfiq
% Multimedia Labratory, The Edward S. Rogers Sr. Dept of Electrical and
% Computer Engineering, University of Toronto

%**************************************************************************
% This function uses Akrum's function to create a Rayleigh fading channel
% coefficeints. The Majority of the code in this function is extracted from
% Akrums "freqflat_rayleigh_2.m" function.
%
%       -> osrate : over sampling rate
%       -> N : size
%       -> T : Bit Period
%**************************************************************************

%% ========= Define Variables ==========
% ======================================
dtf = T / osrate;
K = length( ones(1, osrate*N)) ./ osrate;
fdt = 0.005;
fd = fdt /T;

% Nummber of Samples
nsmple= K*osrate;
tt=[0:nsmple-1]*dtf;

%% ======== Setting Jakes Parameters ===
% ======================================
wd =2*pi*fd;
N=4*4*4; %as used in the paper
N0=N/4;

betan=pi*[1:N0]/N0;
alphan=2*pi*([1:N0]-0.5)/N;
wn=wd*cos(alphan);

%uniformly distributed random phase per path
thetan=2*pi*rand(1,N0);
%% ======== Creating the channel =======
% ======================================
ch=zeros(1,nsmple);

for nn=1:N0
    ch=ch+exp(j*betan(nn))*cos(wn(nn)*tt+thetan(nn));
end

%normalization
Chan =ch*sqrt(2/N0);
Chan = Chan.'; 

