function []= Plotting (Fin)
% Version 1.2
% Last Modified: May 24th, 2009
% Ali Tawfiq
% Multimedia Labratory, The Edward S. Rogers Sr. Dept of Electrical and
% Computer Engineering, University of Toronto

%**************************************************************************
%       Fin     -> L: Length of signal
%               -> itt: number of iterations
%               -> Mod: Modulation Type (refer to 'Mapping.m' for allowed
%                        types)
%               -> M: M-ary, binary (2), quade (4) or 2^n
%               -> k: Number of bits per symbol
%               -> Block: String for block type (refer to 'Mapping.m')
%               -> BlockL: Length of blocks (refer to 'Mapping.m')
%               -> Numtx: Number of transmit antennas
%               -> Numrx: Number of receive antennas
%               -> SNR: a vector of SNR values
%               -> sBER: a temporary vector to store the computed BER
%               -> BER: a zero vector to store the computed BER
%               -> Out: a zero vector to store the final received signal
%                       to be be saved for reference
%               -> InSig: The input signal in bits
%               -> S: Numtx column vectors representing the split input
%                      signal
%               -> Saving: 'backup' for saving the data. 
%               -> InSym: Numtx column vectors of the modulated signal.
%               -> Px: Power of signal (1 for all psk, diff for QAM)
%               Filter Parameters:
%               -> r: Roll-off-factor Used in raised cosine filter
%               -> T: Bit period
%               -> dt:  Duration
%               -> FltrType: The type of filter generated. 
%               -> nsamp: oversampling rate
%               -> Delay: The delay experienced in the filter
%               -> fltr: The generated filter (To be applied in Transmit.m
%                        and Receiver.m)
%**************************************************************************

%% =================== Plotting ==========================
%%========================================================
BitError = mean(Fin.BER);
semilogy (Fin.SNR, BitError, '-*r');
title('SNR Vs BER');
xlabel('SNR (dB)'); ylabel('BER');
S1= sprintf('%s-%s (%d,%d)', Fin.Mod,Fin.FltrType, Fin. L, Fin.itt);h=legend(S1,1);
set(h,'Interpreter','none');
grid on;
S1= sprintf('./Output/%s-%s (%d, %d)', Fin.Mod,Fin.FltrType, Fin. L, Fin.itt);
name = strcat (S1, sprintf('.eps'));
print('-depsc2',name)
name = strcat (S1, sprintf('.fig'));
saveas(gcf, name);
