function Fout_tx = Transmit (ii, Fin)
% Version 1.2
% Last Modified: May 24th, 2009
% Ali Tawfiq
% Multimedia Labratory, The Edward S. Rogers Sr. Dept of Electrical and
% Computer Engineering, University of Toronto

%**************************************************************************
%       ii      -> Itteration read at this instance
%       Fin     -> L: Length of signal
%               -> itt: number of iterations
%               -> Mod: Modulation Type (refer to 'Mapping.m' for allowed
%                        types)
%               -> M: M-ary, binary (2), quade (4) or 2^n
%               -> k: Number of bits per symbol
%               -> Block: String for block type (refer to 'Mapping.m')
%               -> BlockL: Length of blocks (refer to 'Mapping.m')
%               -> Numtx: Number of transmit antennas
%               -> Numrx: Number of receive antennas
%               -> SNR: a vector of SNR values
%               -> sBER: a temporary vector to store the computed BER
%               -> BER: a zero vector to store the computed BER
%               -> Out: a zero vector to store the final received signal
%                       to be be saved for reference
%               -> InSig: The input signal in bits
%               -> S: Numtx column vectors representing the split input
%                      signal
%               -> Saving: 'backup' for saving the data. 
%               -> InSym: Numtx column vectors of the modulated signal.
%               -> Px: Power of signal (1 for all psk, diff for QAM)
%               Filter Parameters:
%               -> r: Roll-off-factor Used in raised cosine filter
%               -> T: Bit period
%               -> dt:  Duration
%               -> FltrType: The type of filter generated. 
%               -> nsamp: oversampling rate
%               -> Delay: The delay experienced in the filter
%               -> fltr: The generated filter (To be applied in Transmit.m
%                        and Receiver.m)
%       Parameters added in this module:
%       Fout_tx -> tx[1:Numtx] = data transmitted from each antenna
%**************************************************************************

%% ==================== Transmitting =====================
% ========================================================
    %Since we are now in the main for loop of the 'Main.m' function,  we
    %will be transmitting the signal in pieces, exactly 'itt' number of
    %smaller chuncks. Here below we extract these pieces and start the
    %transmission process. 
    for oo= 1: Fin.Numtx
        X(:,oo) = Fin.InSym(((ii-1)*Fin.L/Fin.Numtx)+1 : ii*Fin.L/Fin.Numtx, oo);
    end

    %Sequence to be transmitted by each antenna
    tx0 = reshape([X(:,1),-conj(X(:,2))].',1,[]);
    tx1 = reshape([X(:,2), conj(X(:,1))].',1,[]);
    
    % Upsample and apply square root raised cosine filter.
    tx0=upsample(tx0,Fin.nsamp); len_tx= length(tx0);
    tx1=upsample(tx1,Fin.nsamp);
    
    % Account for the delay the filter has
    tx00= zeros(1,len_tx + Fin.Delay*2); tx00(:,1:len_tx)=tx0(:,1:len_tx);
    tx11= zeros(1,len_tx + Fin.Delay*2); tx11(:,1:len_tx)=tx1(:,1:len_tx);
    
    Fout_tx.tx(:,1) = filter(Fin.fltr,1,tx00).';
    Fout_tx.tx(:,2) = filter(Fin.fltr,1,tx11).';
    
    
    